@@ -6,6 +6,7 @@ from sqlalchemy.util import OrderedSet
 import re
 from .render import _user_defined_render
 import contextlib
+from alembic.ddl.base import _fk_spec
 
 log = logging.getLogger(__name__)
 
@@ -112,6 +113,9 @@ def _compare_tables(conn_table_names, metadata_table_names,
                                              conn_table,
                                              metadata_table,
                                              diffs, autogen_context, inspector)
+                _compare_foreign_keys(s, tname, object_filters, conn_table,
+                                      metadata_table, diffs, autogen_context,
+                                      inspector)
 
     # TODO:
     # table constraints
@@ -135,6 +139,25 @@ def _make_unique_constraint(params, conn_table):
     )
 
 
+def _make_foreign_key(params, conn_table):
+    tname = params['referred_table']
+    if params['referred_schema']:
+        tname = "%s.%s" % (params['referred_schema'], tname)
+
+    const = sa_schema.ForeignKeyConstraint(
+        [conn_table.c[cname] for cname in params['constrained_columns']],
+        ["%s.%s" % (tname, n) for n in params['referred_columns']],
+        onupdate=params.get('onupdate'),
+        ondelete=params.get('ondelete'),
+        deferrable=params.get('deferrable'),
+        initially=params.get('initially'),
+        name=params['name']
+    )
+    # needed by 0.7
+    conn_table.append_constraint(const)
+    return const
+
+
 @contextlib.contextmanager
 def _compare_columns(schema, tname, object_filters, conn_table, metadata_table,
                      diffs, autogen_context, inspector):
@@ -190,7 +213,6 @@ def _compare_columns(schema, tname, object_filters, conn_table, metadata_table,
             log.info("Detected removed column '%s.%s'", name, cname)
 
 
-
 class _constraint_sig(object):
 
     def __eq__(self, other):
@@ -231,6 +253,20 @@ class _ix_constraint_sig(_constraint_sig):
         return _get_index_column_names(self.const)
 
 
+class _fk_constraint_sig(_constraint_sig):
+    def __init__(self, const):
+        self.const = const
+        self.name = const.name
+        self.source_schema, self.source_table, \
+            self.source_columns, self.target_schema, self.target_table, \
+            self.target_columns = _fk_spec(const)
+
+        self.sig = (
+            self.source_schema, self.source_table, tuple(self.source_columns),
+            self.target_schema, self.target_table, tuple(self.target_columns)
+        )
+
+
 def _get_index_column_names(idx):
     if compat.sqla_08:
         return [getattr(exp, "name", None) for exp in idx.expressions]
@@ -566,3 +602,80 @@ def _compare_server_default(schema, tname, cname, conn_col, metadata_col,
                  tname,
                  cname
                  )
+
+
+def _compare_foreign_keys(schema, tname, object_filters, conn_table,
+                          metadata_table, diffs, autogen_context, inspector):
+
+    # if we're doing CREATE TABLE, all FKs are created
+    # inline within the table def
+    if conn_table is None:
+        return
+
+    metadata_fks = set(
+        fk for fk in metadata_table.constraints
+        if isinstance(fk, sa_schema.ForeignKeyConstraint)
+    )
+    metadata_fks = set(_fk_constraint_sig(fk) for fk in metadata_fks)
+
+    conn_fks = inspector.get_foreign_keys(tname, schema=schema)
+    conn_fks = set(_fk_constraint_sig(_make_foreign_key(const, conn_table))
+                   for const in conn_fks)
+
+    conn_fks_by_sig = dict(
+        (c.sig, c) for c in conn_fks
+    )
+    metadata_fks_by_sig = dict(
+        (c.sig, c) for c in metadata_fks
+    )
+
+    metadata_fks_by_name = dict(
+        (c.name, c) for c in metadata_fks if c.name is not None
+    )
+    conn_fks_by_name = dict(
+        (c.name, c) for c in conn_fks if c.name is not None
+    )
+
+    def _add_fk(obj, compare_to):
+        if _run_filters(
+                obj.const, obj.name, "foreign_key_constraint", False,
+                compare_to, object_filters):
+            diffs.append(('add_fk', const.const))
+
+            log.info(
+                "Detected added foreign key (%s)(%s) on table %s%s",
+                ", ".join(obj.source_columns),
+                ", ".join(obj.target_columns),
+                "%s." % obj.source_schema if obj.source_schema else "",
+                obj.source_table)
+
+    def _remove_fk(obj, compare_to):
+        if _run_filters(
+                obj.const, obj.name, "foreign_key_constraint", True,
+                compare_to, object_filters):
+            diffs.append(('remove_fk', obj.const))
+            log.info(
+                "Detected removed foreign key (%s)(%s) on table %s%s",
+                ", ".join(obj.source_columns),
+                ", ".join(obj.target_columns),
+                "%s." % obj.source_schema if obj.source_schema else "",
+                obj.source_table)
+
+    # so far it appears we don't need to do this by name at all.
+    # SQLite doesn't preserve constraint names anyway
+
+    for removed_sig in set(conn_fks_by_sig).difference(metadata_fks_by_sig):
+        const = conn_fks_by_sig[removed_sig]
+        if removed_sig not in metadata_fks_by_sig:
+            compare_to = metadata_fks_by_name[const.name].const \
+                if const.name in metadata_fks_by_name else None
+            _remove_fk(const, compare_to)
+
+    for added_sig in set(metadata_fks_by_sig).difference(conn_fks_by_sig):
+        const = metadata_fks_by_sig[added_sig]
+        if added_sig not in conn_fks_by_sig:
+            compare_to = conn_fks_by_name[const.name].const \
+                if const.name in conn_fks_by_name else None
+            _add_fk(const, compare_to)
+
+    return diffs
