@@ -331,44 +331,52 @@ class ScriptDirectory(object):
             filtered_heads = self.revision_map.filter_for_lineage(
                 heads, revision, include_dependencies=True)
 
-            dest = self.get_revision(revision)
+            steps = []
 
-            if dest is None:
-                # dest is 'base'.  Return a "delete branch" migration
-                # for all applicable heads.
-                return [
-                    migration.StampStep(head.revision, None, False, True)
-                    for head in filtered_heads
-                ]
-            elif dest in filtered_heads:
-                # the dest is already in the version table, do nothing.
-                return []
+            dests = self.get_revisions(revision) or [None]
+            for dest in dests:
+                if dest is None:
+                    # dest is 'base'.  Return a "delete branch" migration
+                    # for all applicable heads.
+                    steps.extend([
+                        migration.StampStep(head.revision, None, False, True)
+                        for head in filtered_heads
+                    ])
+                    continue
+                elif dest in filtered_heads:
+                    # the dest is already in the version table, do nothing.
+                    continue
 
-            # figure out if the dest is a descendant or an
-            # ancestor of the selected nodes
-            descendants = set(self.revision_map._get_descendant_nodes([dest]))
-            ancestors = set(self.revision_map._get_ancestor_nodes([dest]))
+                # figure out if the dest is a descendant or an
+                # ancestor of the selected nodes
+                descendants = set(
+                    self.revision_map._get_descendant_nodes([dest]))
+                ancestors = set(self.revision_map._get_ancestor_nodes([dest]))
 
-            if descendants.intersection(filtered_heads):
-                # heads are above the target, so this is a downgrade.
-                # we can treat them as a "merge", single step.
-                assert not ancestors.intersection(filtered_heads)
-                todo_heads = [head.revision for head in filtered_heads]
-                step = migration.StampStep(
-                    todo_heads, dest.revision, False, False)
-                return [step]
-            elif ancestors.intersection(filtered_heads):
-                # heads are below the target, so this is an upgrade.
-                # we can treat them as a "merge", single step.
-                todo_heads = [head.revision for head in filtered_heads]
-                step = migration.StampStep(
-                    todo_heads, dest.revision, True, False)
-                return [step]
-            else:
-                # destination is in a branch not represented,
-                # treat it as new branch
-                step = migration.StampStep((), dest.revision, True, True)
-                return [step]
+                if descendants.intersection(filtered_heads):
+                    # heads are above the target, so this is a downgrade.
+                    # we can treat them as a "merge", single step.
+                    assert not ancestors.intersection(filtered_heads)
+                    todo_heads = [head.revision for head in filtered_heads]
+                    step = migration.StampStep(
+                        todo_heads, dest.revision, False, False)
+                    steps.append(step)
+                    continue
+                elif ancestors.intersection(filtered_heads):
+                    # heads are below the target, so this is an upgrade.
+                    # we can treat them as a "merge", single step.
+                    todo_heads = [head.revision for head in filtered_heads]
+                    step = migration.StampStep(
+                        todo_heads, dest.revision, True, False)
+                    steps.append(step)
+                    continue
+                else:
+                    # destination is in a branch not represented,
+                    # treat it as new branch
+                    step = migration.StampStep((), dest.revision, True, True)
+                    steps.append(step)
+                    continue
+            return steps
 
     def run_env(self):
         """Run the script environment.
