@@ -2,6 +2,7 @@ from alembic.testing.fixtures import TestBase
 from alembic.testing import eq_, assert_raises_message
 from alembic.revision import RevisionMap, Revision, MultipleHeads, \
     RevisionError
+from . import _large_map
 
 
 class APITest(TestBase):
@@ -619,6 +620,17 @@ class BranchTravellingTest(DownIterateTest):
             inclusive=False
         )
 
+    def test_ancestor_nodes(self):
+        merge = self.map.get_revision("merge")
+        eq_(
+            set(
+                rev.revision
+                for rev in self.map._get_ancestor_nodes([merge], check=True)
+            ),
+            set(['a1', 'e2b2', 'e2b1', 'cb2', 'merge',
+                'a3', 'a2', 'b1', 'b2', 'db1', 'db2', 'cb1'])
+        )
+
 
 class MultipleBaseTest(DownIterateTest):
     def setUp(self):
@@ -901,3 +913,31 @@ class MultipleBaseCrossDependencyTestTwo(DownIterateTest):
             ['d3', 'c3', 'b3', 'a3', 'base3']
         )
 
+
+class LargeMapTest(DownIterateTest):
+    def setUp(self):
+        self.map = _large_map.map_
+
+    def test_all(self):
+        raw = [r for r in self.map._revision_map.values() if r is not None]
+
+        revs = [
+            rev for rev in
+            self.map.iterate_revisions(
+                "heads", "base"
+            )
+        ]
+
+        eq_(set(raw), set(revs))
+
+        for idx, rev in enumerate(revs):
+            ancestors = set(
+                self.map._get_ancestor_nodes([rev])).difference([rev])
+            descendants = set(
+                self.map._get_descendant_nodes([rev])).difference([rev])
+
+            assert not ancestors.intersection(descendants)
+
+            remaining = set(revs[idx + 1:])
+            if remaining:
+                assert remaining.intersection(ancestors)
